###################################################
### chunk number 1: loadLibs
###################################################
library(doSMP)
w <- startWorkers(workerCount=4)
registerDoSMP(w)
foreach(i=1:3) %dopar% sqrt(i)


###################################################
### chunk number 2: bootpar
###################################################
x <- iris[which(iris[,5] != "setosa"), c(1,5)]
trials <- 10000

chunkSize <- ceiling(trials / getDoParWorkers())
smpopts <- list(chunkSize=chunkSize)

ptime <- system.time({
  r <- foreach(icount(trials), .combine=cbind, .options.smp=smpopts) %dopar% {
    ind <- sample(100, 100, replace=TRUE)
    result1 <- glm(x[ind,2]~x[ind,1], family=binomial(logit))
    coefficients(result1)
  }
})[3]
ptime


###################################################
### chunk number 3: bootseq
###################################################
stime <- system.time({
  r <- foreach(icount(trials), .combine=cbind) %do% {
    ind <- sample(100, 100, replace=TRUE)
    result1 <- glm(x[ind,2]~x[ind,1], family=binomial(logit))
    coefficients(result1)
  }
})[3]
stime


###################################################
### chunk number 4: getDoParWorkers
###################################################
getDoParWorkers()


###################################################
### chunk number 5: getDoParName
###################################################
getDoParName()
getDoParVersion()


###################################################
### chunk number 6: options
###################################################
smpopts <- list(chunkSize=2)
foreach(i=1:6, .options.smp=smpopts) %dopar% sqrt(i)


###################################################
### chunk number 7: stopworkers
###################################################
stopWorkers(w)


